# p10k edit

[![PyPI - Version](https://img.shields.io/pypi/v/p10k-edit.svg)](https://pypi.org/project/p10k-edit)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/p10k-edit.svg)](https://pypi.org/project/p10k-edit)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install p10k-edit
```

## License

`p10k-edit` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
